==> phyloTop_2.0.1.tar.gz: phyloTop/R/deprecated.R <==
baseAnalysis <- function(...) {
  .Deprecated("phyloTop", package="phyloTop")
}

baseCreate <- function(...) {
  .Deprecated("phyloTop", package="phyloTop")
}

baseListAnalysis <- function(...) {
  .Deprecated("phyloTop", package="phyloTop")
}

baseListCreate <- function(...) {
  .Deprecated("phyloTop", package="phyloTop")
}

classifyConfigFive <- function(...) {
  .Deprecated("nConfig", package="phyloTop")
}

classifyConfigFour <- function(...) {
  .Deprecated("nConfig", package="phyloTop")
}

configFind <- function(...) {
  .Deprecated("nConfig", package="phyloTop")
}

configTop <- function(...) {
  .Deprecated("nConfig", package="phyloTop")
}

dists <- function(...) {
  .Deprecated("getDepths", package="phyloTop")
}

fAvgLadder <- function(...) {
  .Deprecated("avgLadder", package="phyloTop")
}

fColless <- function(...) {
  .Deprecated("colless.phylo", package="phyloTop")
}

fNConfig <- function(...) {
  .Deprecated("nConfig", package="phyloTop")
}

fNLadders <- function(...) {
  .Deprecated("ladderSizes", package="phyloTop")
}

fWidths <- function(...) {
  .Deprecated("widths", package="phyloTop")
}

idNodeLabel <- function(...) {
  .Deprecated("phyloTop", package="phyloTop", 
              "Function deprecated: no longer needed now that functions use phylo objects.")
}

ladderDist <- function(...) {
  .Deprecated("ladderSizes", package="phyloTop")
}

ladderNums <- function(...) {
  .Deprecated("ladderSizes", package="phyloTop")
}

laddItr <- function(...) {
  .Deprecated("ladderSizes", package="phyloTop")
}

makeTransTree <- function(...) {
  .Deprecated("makeEpiRecord", package="phyloTop", 
              "Function deprecated: use instead the new function makeEpiRecord")
}

nDescendants <- function(...) {
  .Deprecated("phyloTop", package="phyloTop",
              "Function deprecated: number of descendants is handled within the relevant functions.")
}

nLadders <- function(...) {
  .Deprecated("ladderSizes", package="phyloTop")
}

nodeApply <- function(...) {
  .Deprecated("phyloTop", package="phyloTop",
              "Function deprecated: no longer needed now that functions use phylo objects.")
}

nodeFrac <- function(...) {
  .Deprecated("phyloTop", package="phyloTop",
              "Function deprecated. See nodeImbFrac and nodeDepthFrac for new node threshold functions.")
}

nTipChildren <- function(...) {
  .Deprecated("nConfig", package="phyloTop")
}

nTipDescendants <- function(...) {
  .Deprecated("nConfig", package="phyloTop",
              "Function deprecated: number of tip descendants is given within the output of nConfig.")
}

rootLaddDist <- function(...) {
  .Deprecated("ladderSizes", package="phyloTop")
}

sortmyepi <- function(...) {
  .Deprecated("getLabGenealogy", package="phyloTop",
              "Function deprecated: now a line within getLabGenealogy")
}

topSumm <- function(...) {
  .Deprecated("phyloTop", package="phyloTop")
}

treeListSummary <- function(...) {
  .Deprecated("phyloTop", package="phyloTop")
}

==> phyloTop_2.1.3.tar.gz: phyloTop/R/deprecated.R <==
baseAnalysis <- function(...) {
  .Deprecated("phyloTop", package="phyloTop")
}

baseCreate <- function(...) {
  .Deprecated("phyloTop", package="phyloTop")
}

baseListAnalysis <- function(...) {
  .Deprecated("phyloTop", package="phyloTop")
}

baseListCreate <- function(...) {
  .Deprecated("phyloTop", package="phyloTop")
}

classifyConfigFive <- function(...) {
  .Deprecated("nConfig", package="phyloTop")
}

classifyConfigFour <- function(...) {
  .Deprecated("nConfig", package="phyloTop")
}

configFind <- function(...) {
  .Deprecated("nConfig", package="phyloTop")
}

configTop <- function(...) {
  .Deprecated("nConfig", package="phyloTop")
}

dists <- function(...) {
  .Deprecated("getDepths", package="phyloTop")
}

fAvgLadder <- function(...) {
  .Deprecated("avgLadder", package="phyloTop")
}

fColless <- function(...) {
  .Deprecated("colless.phylo", package="phyloTop")
}

fNConfig <- function(...) {
  .Deprecated("nConfig", package="phyloTop")
}

fNLadders <- function(...) {
  .Deprecated("ladderSizes", package="phyloTop")
}

fWidths <- function(...) {
  .Deprecated("widths", package="phyloTop")
}

idNodeLabel <- function(...) {
  .Deprecated("phyloTop", package="phyloTop", 
              "Function deprecated: no longer needed now that functions use phylo objects.")
}

ladderDist <- function(...) {
  .Deprecated("ladderSizes", package="phyloTop")
}

ladderNums <- function(...) {
  .Deprecated("ladderSizes", package="phyloTop")
}

laddItr <- function(...) {
  .Deprecated("ladderSizes", package="phyloTop")
}

makeTransTree <- function(...) {
  .Deprecated("makeEpiRecord", package="phyloTop", 
              "Function deprecated: use instead the new function makeEpiRecord")
}

nDescendants <- function(...) {
  .Deprecated("phyloTop", package="phyloTop",
              "Function deprecated: number of descendants is handled within the relevant functions.")
}

nLadders <- function(...) {
  .Deprecated("ladderSizes", package="phyloTop")
}

nodeApply <- function(...) {
  .Deprecated("phyloTop", package="phyloTop",
              "Function deprecated: no longer needed now that functions use phylo objects.")
}

nodeFrac <- function(...) {
  .Deprecated("phyloTop", package="phyloTop",
              "Function deprecated. See nodeImbFrac and nodeDepthFrac for new node threshold functions.")
}

nTipChildren <- function(...) {
  .Deprecated("nConfig", package="phyloTop")
}

nTipDescendants <- function(...) {
  .Deprecated("treeImb", package="phyloTop")
}

rootLaddDist <- function(...) {
  .Deprecated("ladderSizes", package="phyloTop")
}

sortmyepi <- function(...) {
  .Deprecated("getLabGenealogy", package="phyloTop",
              "Function deprecated: now a line within getLabGenealogy")
}

topSumm <- function(...) {
  .Deprecated("phyloTop", package="phyloTop")
}

treeListSummary <- function(...) {
  .Deprecated("phyloTop", package="phyloTop")
}
